@@ -1,6 +1,6 @@
 use std::collections::HashMap;
 use itertools::Itertools;
-use crate::config::AppConfig;
+use crate::config::AppCfg;
 use crate::util::k8s::ApiResourceType;
 use crate::util::k8s::kubectl::ApiResourceTypes;
 use crate::k8s::ApiResource;
@@ -12,7 +12,7 @@ mod config;
 fn main() {
     util::logging::init();
 
-    let app_config: AppConfig = config::AppConfig::from_cli_args();
+    let app_config: AppCfg = config::AppCfg::from_cli_args();
 
     log::info!("Checking app configuration..");
     check_root_output_dir(&app_config);
@@ -37,7 +37,7 @@ fn main() {
     for (namespace_opt, resources) in resources_by_namespace {
         let output_dir: String = make_resource_output_dir(&app_config, &namespace_opt).expect("Unable to create output dir");
         for resource in resources {
-            let file_path = make_resource_file_path(&output_dir, resource).expect("unable to make resource file path");
+            let file_path = make_resource_file_path(&output_dir, resource);
             let output_string = make_resource_file_contents(&app_config, resource).unwrap_or_else(|err| panic!("unable to make resource file contents for: {}, due to {:?}", file_path, err));
             std::fs::write(&file_path, &output_string).unwrap_or_else(|err| panic!("Unable to write file {}, due to {:?}", file_path, err));
         }
@@ -46,7 +46,7 @@ fn main() {
     log::info!("DONE!");
 }
 
-fn make_resource_output_dir(app_config: &config::AppConfig, namespace_opt: &Option<String>) -> std::io::Result<String> {
+fn make_resource_output_dir(app_config: &config::AppCfg, namespace_opt: &Option<String>) -> std::io::Result<String> {
     let output_dir: String = match namespace_opt {
         Some(namespace) => app_config.output_dir.to_string() + "/" + &namespace.to_string(),
         None => app_config.output_dir.to_string(),
@@ -57,9 +57,9 @@ fn make_resource_output_dir(app_config: &config::AppConfig, namespace_opt: &Opti
     Ok(output_dir)
 }
 
-fn make_resource_file_path(output_dir: &str, resource: &k8s::ApiResource) -> std::io::Result<String> {
+fn make_resource_file_path(output_dir: &str, resource: &k8s::ApiResource) -> String {
     let file_name: String = {
-        let file_name_base: String = util::file::sanitize(&resource.parsed_fields.metadata.name)? + "." + &util::file::sanitize(&resource.qualified_type_name())? + ".yaml";
+        let file_name_base: String = util::file::sanitize(&resource.parsed_fields.metadata.name) + "." + &util::file::sanitize(&resource.qualified_type_name()) + ".yaml";
         if resource.is_secret() {
             file_name_base + ".aes"
         } else {
@@ -67,10 +67,10 @@ fn make_resource_file_path(output_dir: &str, resource: &k8s::ApiResource) -> std
         }
     };
 
-    Ok(output_dir.to_string() + "/" + &file_name)
+    output_dir.to_string() + "/" + &file_name
 }
 
-fn make_resource_file_contents(app_config: &config::AppConfig, resource: &k8s::ApiResource) -> Result<String, crypt::EncryptError> {
+fn make_resource_file_contents(app_config: &config::AppCfg, resource: &k8s::ApiResource) -> Result<String, crypt::EncryptError> {
     if resource.is_secret() {
         let encryption_key = app_config.secrets_encryption_key.as_ref().expect("BUG: encryption key has been removed or was never set");
         let encrypted = util::crypt::encrypt(&resource.raw_source, encryption_key)?;
@@ -80,7 +80,7 @@ fn make_resource_file_contents(app_config: &config::AppConfig, resource: &k8s::A
     }
 }
 
-fn check_root_output_dir(app_config: &config::AppConfig) {
+fn check_root_output_dir(app_config: &config::AppCfg) {
     if app_config.delete_previous_dir {
         util::file::delete_all_if_exists(&app_config.output_dir)
             .unwrap_or_else(|err| panic!("unable to delete output dir: {}, due to {:?}", &app_config.output_dir, err));
